<?php
    /*
    * PDFFP Plugin for insert a PDF icon with this link in a article for Joomla! 1.5.x
    * Version 1.0
    * Creation date: Aot 2011
    * Author: Fabrice4821 - www.gmapfp.org
    * Author email: webmaster@gmapfp.org
    * License GNU/GPL
    */

jimport('joomla.application.component.controller');

class PDFFPPluginController extends JController
{
    function display()
    {
        global $mainframe;

        $vName = JRequest::getCmd('view', 'grid');
        $vLayout = JRequest::getCmd( 'layout', 'default' );
        $mName = 'grid';

        $document = &JFactory::getDocument();
        $vType      = $document->getType();

        // Get/Create the view
        $view = &$this->getView( $vName, $vType);

        // Get/Create the model
        if ($model = &$this->getModel($mName)) {
            // Push the model into the view (as default)
            $view->setModel($model, true);
        }

        // Set the layout
        $view->setLayout($vLayout);

        // Display the view
        $view->display();
    }

	function upload()
	{
		global $mainframe;

		// Check for request forgeries
		JRequest::checkToken( 'request' ) or jexit( 'Invalid Token' );
		$file 		= JRequest::getVar( 'Filedata', '', 'files', 'array' );
		$return		= JRequest::getVar( 'return-url', null, 'post', 'base64' );
		$err		= null;

		// Set FTP credentials, if given
		jimport('joomla.client.helper');
		JClientHelper::setCredentialsFromRequest('ftp');

		if (!array_key_exists('name', $file)) {
			JError::raiseNotice(100, JText::_('Error. File not exists'));
			// REDIRECT
			if ($return) {
				$mainframe->redirect(base64_decode($return));
			} else {
				$mainframe->redirect('index.php?option=com_plugin_pdffp&tmpl=component');
			}
			return;
		}

		// Make the filename safe
		jimport('joomla.filesystem.file');
		$file['name']	= JFile::makeSafe($file['name']);

		if (isset($file['name'])) {
			$filepath = JPath::clean(COM_PDF_BASE.DS.strtolower($file['name']));

			if (!$this->canUpload( $file, $err )) {
				JError::raiseNotice(100, JText::_($err));
				// REDIRECT
				if ($return) {
					$mainframe->redirect(base64_decode($return));
				}
				return;
			}

			if (JFile::exists($filepath)) {
				JError::raiseNotice(100, JText::_('Error. File already exists'));
				// REDIRECT
				if ($return) {
					$mainframe->redirect(base64_decode($return));
				}
				return;
			}

			if (!JFile::upload($file['tmp_name'], $filepath)) {
				JError::raiseWarning(100, JText::_('Error. Unable to upload file'));
				// REDIRECT
				if ($return) {
					$mainframe->redirect(base64_decode($return));
				}
				return;
			} else {
				$mainframe->enqueueMessage(JText::_('Upload complete'));
				// REDIRECT
				if ($return) {
					$mainframe->redirect(base64_decode($return));
				}
				return;
			}
		} else {
			$mainframe->redirect('index.php', 'Invalid Request', 'error');
		}
	}

	function delete()
	{
		global $mainframe;

		JRequest::checkToken( 'request' ) or jexit( 'Invalid Token' );

		// Set FTP credentials, if given
		jimport('joomla.client.helper');
		JClientHelper::setCredentialsFromRequest('ftp');

		// Get some data from the request
		$tmpl	= JRequest::getCmd( 'tmpl' );
		$files	= JRequest::getVar( 'rm', array(), '', 'array' );
		$folder = COM_PDF_BASE;

		// Initialize variables
		$msg = array();
		$ret = true;

		if (count($files)) {
			foreach ($files as $file)
			{
				if ($file !== JFile::makeSafe($file)) {
					JError::raiseWarning(100, JText::_('Unable to delete:').htmlspecialchars($file, ENT_COMPAT, 'UTF-8').' '.JText::_('WARNFILENAME'));
					continue;
				}

				$fullPath = JPath::clean($folder.DS.$file);
				if (is_file($fullPath)) {
					$ret |= !JFile::delete($fullPath);
				}
			}
		}
		if ($tmpl == 'component') {
			// We are inside the iframe
			$mainframe->redirect('index.php?option=com_plugin_pdffp&view=PDFsList&tmpl=component');
		} else {
			$mainframe->redirect('index.php?option=com_plugin_pdffp&view=PDFsList');
		}
	}

	function canUpload( $file, &$err )
	{
		$params =& JComponentHelper::getParams('com_media');
		if(empty($file['name'])) {
			$err = 'Please input a file for upload';
			return false;
		}

		jimport('joomla.filesystem.file');
		if ($file['name'] !== JFile::makesafe($file['name'])) {
			$err = 'WARNFILENAME';
			return false;
		}

		$format = strtolower(JFile::getExt($file['name']));

		if ($format != 'pdf')
		{
			$err = 'WARNFILETYPE';
			return false;
		}

		$maxSize = (int) $params->get( 'upload_maxsize', 0 );
		if ($maxSize > 0 && (int) $file['size'] > $maxSize)
		{
			$err = 'WARNFILETOOLARGE';
			return false;
		}

		return true;
	}

}
